@@ -33,7 +33,8 @@ class AbstractWrapper():
       self.__init_interfaces()
       self.__init_dbus_signals()
       self.post_init()
-      self.get_status()
+      try: self.get_status()
+      except: pass
 
   def pre_init(self):
     raise NotImplementedError("AbstractWrapper.pre_init() must be implemented")
